@@ -15,4 +15,4 @@ EXC_TESTS = [
 ]
 
 $: << 'lib' << 'test' << '.'
-(Dir['{spec,test}/**/test_*.rb'] - EXC_TESTS).each { |f| require f }
+(Dir['test/{unit,functional}/**/test_*.rb'] - EXC_TESTS).each { |f| require f }
